import os
import sys

try:
    HIBP_API_KEY = os.environ.get("HIBP_API_KEY")
except Exception:
    print(
        "To use this package, please export your API key:\n"
        "export HIBP_API_KEY='YOUR_API_KEY'"
    )
    sys.exit(0)

HEADERS = {"User-Agent": "hibpy", "hibp-api-key": HIBP_API_KEY}
VERSION = "v3"
BASE_URL = "https://haveibeenpwned.com/"
API_URL = f"https://haveibeenpwned.com/api/{VERSION}"

# Services
# All breaches for an account
BREACHED_ACCOUNT = "breachedaccount"
# All breached sites on HIPB
BREACHES = "breaches"
# Single breached site
BREACH = "breach"
# All data classes (eg: Email addresses, passwords, etc...)
DATA_CLASSES = "dataclasses"
# All pastes for an account
PASTE_ACCOUNT = "pasteaccount"

HTTP_CODES = {
    "400": "400 - Bad Request",
    "401": "401 - Unauthorised",
    "403": "403 - Forbidden",
    "429": "429 - Too Many Requests",
    "503": "503 - Service Unavailable",
}



import setuptools

long_description = """
Python interface to communicate with HaveIBeenPwned.com.
"""

setuptools.setup(
    name="hibp-zetsumeishi",
    version="0.1.1",
    author="zetsumeishi",
    author_email="olivier.loustaunau@gmail.com",
    description="Python interface to communicate with HaveIBeenPwned.com",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/zetsumeishi/hibp",
    packages=setuptools.find_packages(exclude=("tests",)),
    install_requires=["requests"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)



import requests

from .constants import (
    API_URL,
    HEADERS,
    BREACHED_ACCOUNT,
    BREACHES,
    BREACH,
    DATA_CLASSES,
    PASTE_ACCOUNT,
    HTTP_CODES,
)


def get(service, params=None, search_term=None):
    query = f"{API_URL}/{service}"
    if search_term:
        query += f"/{search_term}"
    if params:
        query += f"?{params}"

    response = requests.get(query, headers=HEADERS)
    if response.status_code == 200:
        return response
    elif response.status_code == 404:
        print("No results found")
    else:
        print(f"Something happened: {HTTP_CODES[str(response.status_code)]}")


def breached_account(email, truncate=True, domain=None, unverified=False):
    params = f"truncateResponse={truncate}&includeUnverified={unverified}"
    if domain:
        params += f"&domain={domain}"
    return get(BREACHED_ACCOUNT, params=params, search_term=email)


def breaches(domain=None):
    params = ""
    if domain:
        params = f"domain={domain}"
    return get(BREACHES, params=params)


def breach(breach_name):
    return get(BREACH, search_term=breach_name)


def data_classes():
    return get(DATA_CLASSES)


def paste_account(email):
    return get(PASTE_ACCOUNT, search_term=email)
